bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 1. Aventiure
___________________________________________________ #### Aventivre #### von den nibelvngen
###### 1 | ### Vns ist in alten maeren | wunders vil geseit ### von heleden lobebaeren | von grozer arebeit ### von vroevden hohgeciten | von weinen und von klagen ### von chvener recken striten | muget ir nu wunder hoeren sagen
###### 2 | ### ez wuohs in bvrgonden | ein vil edel magedin ### daz in allen landen | niht schoners mohte sin ### chriemhilt geheizen | si wart ein scoene wip ### darvmbe mvosen degene | vil verliesen den lip
###### 3 | ### der minnechlichen meide | trivten wol gezam ### ir mvoten chvene recken | niemen was ir gram ### ane mazen schone | so was ir edel lip ### der ivnchfrowen tvgende | zierten anderiv wip
###### 4 | ### ir pflagen drie kvnege | edel vnde rich ### gventher vnde gernot | di rechen lobelich ### vnt giselher der ivnge | ein vzerwelter degn ### div frowe was ir swester | di fversten hetens in ir pflegn
###### 5 | ### di herren waren milte | von arde hohe erborn ### mit chraft vnmazen chvene | di rechen vzerchorn ### da zen bvrgonden | so was ir lant genant ### si frvmten starchiv wunder | sit in ezelen lant
###### 6 | ### ze wormeze bi dem rine | si wonten mit ir chraft ### in diente von ir landen | vil stolziv ritterscaft ### mit lobelichen eren | vnz an ir endes zit ### si erstvrben sit iaemerliche | von zweier edelen frowen nit
###### 7 | ### ein richiv kvneginne | frov vote ir mvoter hiez ### ir vater der hiez danchrat | der in div erbe liez ### sit nach sime lebene | ein ellens richer man ### der ovch in siner ivgende | grozer eren vil gewan
###### 8 | ### die drie kvnege waren | als ich gesaget han ### von vil hohem ellen | in waren vndertan ### ovch di besten rechen | von den man hat gesagt ### starch vnt vil chvene | in scarpfen striten vnverzagt
###### 9 | ### daz was von tronege hagene | vnt ovch der brvoder sin ### danchwart der vil snelle | von mezzen ortewin ### di zwene marcgraven | gere vnt ekkewart ### volker von alzeye | mit ganzem ellen wol bewart
###### 10 | ### rvomolt der chvchenmeister | ein tiwerlicher degn ### sindolt vnt hvonolt | dise herren mvosen pflegen ### des hoves vnt der eren | der drier kvnege man ### si heten noch manegen rechen | des ich genennen niene chan
###### 11 | ### danchwart der was marscalch | do was der neve sin ### trvhsaeze des kvneges | von mezzen oertewin ### sindolt der was scenche | ein vzerwelter degn ### hvonolt was chameraere | si chvnden hoher eren pflegn
###### 12 | ### von des hoves chrefte | vnt von ir witen chraft ### von ir vil hohen werdecheit | vnt von ir ritterscaft ### der di herren pflagen | mit vrovden all ir lebn ### des en chvnd iv ze ware | niemen gar ein ende gebn
###### 13 | ### in disen hohen eren | trovmte chriemhilde ### wie si zvge einen valchen | starch scoen vnt wilde ### den ir zwene aren erchrvmmen | daz si daz mvoste sehn ### ir en chvnde in dirre werlde | leider nimmer geschehn
###### 14 | ### den trovm si do sagete | ir mvoter voten ### si ne chvndes niht besceiden | baz der gvoten ### der valche den dv zivhest daz ist ein edel man ### ine welle got behveten dv mvost in sciere vloren han
###### 15 | ### waz saget ir mir von manne | vil liebiv mvoter min ### ane rechen minne | so wil ich immer sin ### svs scoen ich wil beliben | vnz an minen tot ### daz ich von mannes minne | sol gewinnen nimmer not
###### 16 | ### nv versprich ez niht ze sere | sprach aber ir mvoter do ### soltv immer hercenliche | zer werlde werden vro ### daz gesciht von mannes minne | dv wirst ein scoene wip ### ob dir noch got gefveget | eins rehte gvoten ritters lip
###### 17 | ### di rede lat beliben | sprach si frowe min ### ez ist an manegen wiben | vil diche worden scin ### wie liebe mit leide | ze ivngest lonen chan ### ich sol si miden beide | so ne chan mir nimmer missegan
###### 18 | ### chriemhilt in ir mvote | sich minne gar bewach ### sit lebt div vil gvote | vil manigen lieben tac ### daz sine wesse niemen | den minnen wolde ir lip ### sit wart si mit eren | eins vil chuenen recken wip
###### 19 | ### der was der selbe valche | den si in ir trovme sach ### den ir besciet ir mvoter wi sere si daz rach ### an ir naehsten magen die in slvogen sint ### dvrch sin eines sterben starp vil maneger mvoter kint

<<< Übersicht <<< vorige Seite nächste Seite >>>